@@ -36,7 +36,7 @@
 #include <string.h>
 #include <errno.h>
 
-#define VERSION "0.7"
+#define VERSION "1.10"
 
 int test_mode = 0;
 int verbose_mode = 0;
@@ -331,7 +331,7 @@ int main (int argc, char *argv[])
     case 3:
       version ();
     default:
-      error("unrecognized option `%s'", argv[optind]);
+      error("unrecognized option `%s'", argv[optind-1]);
       fprintf(stderr, "Try `run-parts --help' for more information.\n");
       exit (1);
     }
